@@ -31,6 +31,7 @@
 #include <QApplication>
 #include <QCommandLineParser>
 #include <QCommandLineOption>
+#include <QDBusInterface>
 
 #include <DApplication>
 
@@ -82,11 +83,6 @@ void MainWindow::initOriginUI()
     m_sizeTips->hide();
     m_zoomIndicator = new ZoomIndicator(this);
     m_zoomIndicator->hide();
-    m_updateZoomTimer = new QTimer(this);
-
-    connect(m_updateZoomTimer, &QTimer::timeout,
-            m_zoomIndicator, &ZoomIndicator::updatePaintEvent);
-
 
     m_isFirstDrag = false;
     m_isFirstMove = false;
@@ -515,8 +511,6 @@ void MainWindow::mouseMoveEvent(QMouseEvent *ev)
 {
     bool needRepaint = false;
 
-    m_updateZoomTimer->start(200);
-
     if (!m_isShapesWidgetExist) {
         if (m_recordWidth > 0 && m_recordHeight >0 && !m_needSaveScreenshot && this->isVisible()) {
             m_sizeTips->updateTips(QPoint(m_recordX, m_recordY),
@@ -713,6 +707,8 @@ void MainWindow::paintEvent(QPaintEvent *event)
     QRect backgroundRect = QRect(0, 0,
                                  m_backgroundRect.width(), m_backgroundRect.height());
 
+    // FIXME: Under the magnifying glass, it seems to be magnified two times.
+
     m_backgroundPixmap.setDevicePixelRatio(devicePixelRatioF());
     painter.drawPixmap(backgroundRect, m_backgroundPixmap);
 
@@ -928,9 +924,10 @@ void MainWindow::fullScreenshot()
     emit this->hideScreenshotUI();
 //    DDesktopServices::playSystemSoundEffect(DDesktopServices::SSE_Screenshot);
 //    using namespace utils;
-    QPixmap screenShotPix(TempFile::instance()->getFullscreenFileName());
-    saveAction(screenShotPix);
-    sendNotify(m_saveIndex, m_saveFileName);
+
+    TempFile::instance()->setFullScreenPixmap(m_resultPixmap);
+    const auto r = saveAction(m_resultPixmap);
+    sendNotify(m_saveIndex, m_saveFileName, r);
 }
 
 void MainWindow::savePath(const QString &path)
@@ -995,10 +992,9 @@ void MainWindow::saveSpecificedPath(QString path)
     m_sizeTips->setVisible(false);
 
     shotCurrentImg();
+    m_resultPixmap.save(savePath);
 //    DDesktopServices::playSystemSoundEffect(DDesktopServices::SSE_Screenshot);
 
-    QPixmap screenShotPix(TempFile::instance()->getTmpFileName());
-    screenShotPix.save(savePath);
     QStringList actions;
     actions << "_open" << tr("View");
     QVariantMap hints;
@@ -1096,8 +1092,9 @@ void MainWindow::topWindow()
              << "screenShot is null:" << screenShotPix.isNull();
     m_needSaveScreenshot = true;
     //    DDesktopServices::playSystemSoundEffect(DDesktopServices::SSE_Screenshot);
-    saveAction(screenShotPix);
-    sendNotify(m_saveIndex, m_saveFileName);
+
+    const auto r = saveAction(screenShotPix);
+    sendNotify(m_saveIndex, m_saveFileName, r);
 }
 
 void MainWindow::expressSaveScreenshot()
@@ -1136,14 +1133,12 @@ QPixmap MainWindow::getPixmapofRect(const QRect &rect)
 void MainWindow::initBackground()
 {
     m_backgroundPixmap = getPixmapofRect(m_backgroundRect);
-    m_backgroundPixmap.save(TempFile::instance()->getFullscreenFileName(), "PNG");
+    m_resultPixmap = m_backgroundPixmap;
+    TempFile::instance()->setFullScreenPixmap(m_backgroundPixmap);
 }
 
 void MainWindow::shotFullScreen() {
-    QPixmap tmpImg =  getPixmapofRect(m_backgroundRect);
-
-    //    using namespace utils;
-    tmpImg.save(TempFile::instance()->getFullscreenFileName(), "png");
+    m_resultPixmap = getPixmapofRect(m_backgroundRect);
 }
 
 void MainWindow::shotCurrentImg()
@@ -1175,10 +1170,7 @@ void MainWindow::shotCurrentImg()
                   m_recordWidth * ratio,
                   m_recordHeight * ratio );
 
-    QPixmap tmpImg(TempFile::instance()->getFullscreenFileName());
-    tmpImg = tmpImg.copy(target);
-
-    tmpImg.save(TempFile::instance()->getTmpFileName(), "png");
+    m_resultPixmap = m_resultPixmap.copy(target);
 }
 
 void MainWindow::shotImgWidthEffect()
@@ -1193,12 +1185,7 @@ void MainWindow::shotImgWidthEffect()
 //    eventloop.exec();
 
     qDebug() << m_toolBar->isVisible() << m_sizeTips->isVisible();
-    QPixmap tmpImg =    getPixmapofRect(m_shapesWidget->geometry());
-
-    qDebug() << tmpImg.isNull() << tmpImg.size();
-
-//    using namespace utils;
-    tmpImg.save(TempFile::instance()->getTmpFileName(), "png");
+    m_resultPixmap = getPixmapofRect(m_shapesWidget->geometry());
     m_drawNothing = false;
     update();
 }
@@ -1218,12 +1205,11 @@ void MainWindow::saveScreenshot()
 
     shotCurrentImg();
 
-//    using namespace utils;
-    saveAction(TempFile::instance()->getTmpFileName());
-    sendNotify(m_saveIndex, m_saveFileName);
+    const bool r = saveAction(m_resultPixmap);
+    sendNotify(m_saveIndex, m_saveFileName, r);
 }
 
-void MainWindow::saveAction(QPixmap pix)
+bool MainWindow::saveAction(const QPixmap &pix)
 {
     emit releaseEvent();
 
@@ -1280,18 +1266,15 @@ void MainWindow::saveAction(QPixmap pix)
                                                      tr("PNG (*.png);;JPEG (*.jpg *.jpeg);; BMP (*.bmp);; PGM (*.pgm);;"
                                                         "XBM (*.xbm);;XPM(*.xpm)"));
 
-
-        if (QFileInfo(m_saveFileName).isDir()) {
-            qDebug() << "empty fileName";
-            exitApp();
-        }
+        if (m_saveFileName.isEmpty() || QFileInfo(m_saveFileName).isDir())
+            return false;
 
         QString fileSuffix = QFileInfo(m_saveFileName).completeSuffix();
         if (fileSuffix.isEmpty()) {
-                    m_saveFileName = m_saveFileName + ".png";
+            m_saveFileName = m_saveFileName + ".png";
         } else if ( !isValidFormat(fileSuffix)) {
             qWarning() << "The fileName has invalid suffix!" << fileSuffix << m_saveFileName;
-            exitApp();
+            return false;
         }
 
         ConfigSettings::instance()->setValue("common", "default_savepath",
@@ -1339,12 +1322,12 @@ void MainWindow::saveAction(QPixmap pix)
                                                                             Qt::KeepAspectRatio, Qt::FastTransformation);
     }
 
-    if (m_saveIndex ==2 && m_saveFileName.isEmpty()) {
-        exitApp();
-        return;
+    if (m_saveIndex == 2 && m_saveFileName.isEmpty()) {
+        return false;
     } else if (m_saveIndex == 2 || !m_saveFileName.isEmpty()) {
-        screenShotPix.save(m_saveFileName,  QFileInfo(m_saveFileName).suffix().toLocal8Bit());
-    } else if (saveOption != QStandardPaths::TempLocation || m_saveFileName.isEmpty()) {
+        if (!screenShotPix.save(m_saveFileName,  QFileInfo(m_saveFileName).suffix().toLocal8Bit()))
+            return false;
+    } else if (saveOption != QStandardPaths::TempLocation && m_saveFileName.isEmpty()) {
         if (m_selectAreaName.isEmpty()) {
             m_saveFileName = QString("%1/%2_%3.png").arg(QStandardPaths::writableLocation(
                              saveOption)).arg(tr("DeepinScreenshot")).arg(currentTime);
@@ -1352,7 +1335,8 @@ void MainWindow::saveAction(QPixmap pix)
             m_saveFileName = QString("%1/%2_%3_%4.png").arg(QStandardPaths::writableLocation(
                              saveOption)).arg(tr("DeepinScreenshot")).arg(m_selectAreaName).arg(currentTime);
         }
-        screenShotPix.save(m_saveFileName,  "PNG");
+        if (!screenShotPix.save(m_saveFileName,  "PNG"))
+            return false;
     }
 
     if (copyToClipboard) {
@@ -1360,10 +1344,21 @@ void MainWindow::saveAction(QPixmap pix)
         QClipboard* cb = qApp->clipboard();
         cb->setPixmap(screenShotPix, QClipboard::Clipboard);
     }
+
+    return true;
 }
 
-void MainWindow::sendNotify(int saveIndex, QString saveFilePath)
+void MainWindow::sendNotify(int saveIndex, QString saveFilePath, const bool succeed)
 {
+    // failed notify
+    if (!succeed)
+    {
+        const auto tips = tr("Save failed. Please save it in your home directory.");
+        m_notifyDBInterface->Notify("Deepin Screenshot", 0, "deepin-screenshot", QString(), tips, QStringList(), QVariantMap(), 0);
+
+	exit(0);
+    }
+
     QStringList actions;
     actions << "_open" << tr("View");
     QVariantMap hints;
@@ -1409,23 +1404,26 @@ void MainWindow::reloadImage(QString effect)
     shotImgWidthEffect();
     //using namespace utils;
     const int radius = 10;
-    QPixmap tmpImg(TempFile::instance()->getTmpFileName());
+    QPixmap tmpImg = m_resultPixmap;
     int imgWidth = tmpImg.width();
     int imgHeight = tmpImg.height();
+
+    TempFile *tempFile = TempFile::instance();
+
     if (effect == "blur") {
         if (!tmpImg.isNull()) {
             tmpImg = tmpImg.scaled(imgWidth/radius, imgHeight/radius,
                                    Qt::IgnoreAspectRatio, Qt::SmoothTransformation);
             tmpImg = tmpImg.scaled(imgWidth, imgHeight, Qt::IgnoreAspectRatio,
                                    Qt::SmoothTransformation);
-            tmpImg.save(TempFile::instance()->getBlurFileName(), "png");
+            tempFile->setBlurPixmap(tmpImg);
         }
     } else {
         if (!tmpImg.isNull()) {
             tmpImg = tmpImg.scaled(imgWidth/radius, imgHeight/radius,
                                    Qt::IgnoreAspectRatio, Qt::SmoothTransformation);
             tmpImg = tmpImg.scaled(imgWidth, imgHeight);
-            tmpImg.save(TempFile::instance()->getMosaicFileName(), "png");
+            tempFile->setMosaicPixmap(tmpImg);
         }
     }
 }
@@ -1449,17 +1447,14 @@ void MainWindow::onViewShortcut()
 
 void MainWindow::onHelp()
 {
-//    using namespace utils;
-    if (m_manualPro.isNull()) {
-        const QString pro = "dman";
-        const QStringList args("deepin-screenshot");
-        m_manualPro = new QProcess();
-        connect(m_manualPro.data(), SIGNAL(finished(int)),
-                m_manualPro.data(), SLOT(deleteLater()));
-        this->hide();
-        m_manualPro->start(pro, args);
-
+    QDBusInterface iface("com.deepin.Manual.Open",
+                         "/com/deepin/Manual/Open",
+                         "com.deepin.Manual.Open");
+    if (iface.isValid()) {
+        iface.call("ShowManual", "deepin-screenshot");
         exitApp();
+    } else {
+        qWarning() << "manual service not avilable, cannot open manual";
     }
 }
 
